@@ -5,7 +5,8 @@ var indexSectionsWithContent =
   2: "c",
   3: "o",
   4: "abcdegiklmnoprsuw",
-  5: "acfrt"
+  5: "acfrt",
+  6: "o"
 };
 
 var indexSectionNames =
@@ -15,7 +16,8 @@ var indexSectionNames =
   2: "namespaces",
   3: "files",
   4: "functions",
-  5: "typedefs"
+  5: "typedefs",
+  6: "pages"
 };
 
 var indexSectionLabels =
@@ -25,6 +27,7 @@ var indexSectionLabels =
   2: "Namespaces",
   3: "Files",
   4: "Functions",
-  5: "Typedefs"
+  5: "Typedefs",
+  6: "Pages"
 };
 
